<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/dump?lang_cible=sk
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'aucune_donnee' => 'prázdny',
	'avis_probleme_ecriture_fichier' => 'Problém so zápisom do súboru @fichier@',

	// B
	'bouton_restaurer_base' => 'Obnoviť databázu',

	// C
	'confirmer_ecraser_base' => 'Áno, chcem prepísať svoju databázu so zálohou',
	'confirmer_ecraser_tables_selection' => 'Áno, chcem prepísať vybrané tabuľky so zálohou',
	'confirmer_supprimer_sauvegarde' => 'Určite chcete vymazať túto zálohu?',

	// D
	'details_sauvegarde' => 'Podrobnosti o zálohe:',

	// E
	'erreur_aucune_donnee_restauree' => 'Žiadne údaje neboli obnovené',
	'erreur_connect_dump' => 'Server s názvom @dump@ už existuje. Premenujte ho.',
	'erreur_creation_base_sqlite' => 'Nedá sa vytvoriť databáza SQLite pre zálohu',
	'erreur_nom_fichier' => 'Tento názov súboru nie je povolený',
	'erreur_restaurer_verifiez' => 'Opravte chybu, aby ste mohli obnoviť údaje.',
	'erreur_sauvegarde_deja_en_cours' => 'Už máte jednu zálohu, ktorá sa spracúva',
	'erreur_sqlite_indisponible' => 'U vášho poskytovateľa hostingu sa nedá vytvoriť záloha SQLite',
	'erreur_table_absente' => 'Tabuľka @table@ chýba',
	'erreur_table_donnees_manquantes' => 'Tabuľka @table@, chýbajú údaje',
	'erreur_taille_sauvegarde' => 'Zdá sa, že zálohovanie sa nepodarilo. Súbor @fichier@ je buď prázdny, alebo chýba.
',

	// I
	'info_aucune_sauvegarde_trouvee' => 'Žiadna záloha sa nenašla',
	'info_restauration_finie' => 'Hotovo! Záloha @archive@ sa použila na vašu stránku. Môžete',
	'info_restauration_sauvegarde' => 'Obnova zálohy @archive@',
	'info_sauvegarde' => 'Záloha',
	'info_sauvegarde_reussi_02' => 'Databáza bola uložená do súboru @archive@. Môžete',
	'info_sauvegarde_reussi_03' => 'return to the management',
	'info_sauvegarde_reussi_04' => 'svojej stránky.',
	'info_selection_sauvegarde' => 'Rozhodli ste sa obnoviť zálohu @fichier@. Táto operácia sa nedá vrátiť späť.',

	// L
	'label_nom_fichier_restaurer' => 'alebo uveďte názov súboru, ktorý chcete obnoviť',
	'label_nom_fichier_sauvegarde' => 'Názov pre súbor so zálohou',
	'label_selectionnez_fichier' => 'Vyberte súbor zo zoznamu',

	// N
	'nb_donnees' => '@nb@ záznamov',

	// R
	'restauration_en_cours' => 'Obnovuje sa',

	// S
	'sauvegarde_en_cours' => 'Zálohuje sa',
	'sauvegardes_existantes' => 'Existujúce zálohy',
	'selectionnez_table_a_restaurer' => 'Vyberte tabuľky, ktoré treba obnoviť',

	// T
	'texte_admin_tech_01' => 'Táto možnosť vám umožňuje uložiť obsah databázy do súboru uloženého v priečinku @dossier@. Tiež nezabudnite obnoviť celý priečinok @img@, v ktorom sú obrázky a súbory, ktoré sa používajú v článkoch a rubrikách.',
	'texte_admin_tech_02' => 'Pozor: táto záloha môže byť obnovená IBA v takej verzii SPIPu, v ktorej bola vytvorená. Nemôžete "vyprázdniť" databázu a očakávať, že sa po aktualizácii preinštaluje zo zálohy. Viac informácii si môžete prečítať <a href="@spipnet@">v dokumentácii k SPIPu.</a>',
	'texte_restaurer_base' => 'Obnoviť obsah databázy zálohy',
	'texte_restaurer_sauvegarde' => 'Táto možnosť vám umožňuje obnoviť predchádzajúcu verziu databázy zo zálohy. Na tento účel treba súbor so zálohou
presunúť do priečinka @dossier@.
Pri používaní tejto funkcie treba byť obozretný: <b>akékoľvek zmeny ani straty
sa nedajú odvolať.</b>',
	'texte_sauvegarde' => 'Záloha obsahu databázy',
	'texte_sauvegarde_base' => 'Zálohovať databázu',
	'tout_restaurer' => 'Obnoviť všetky tabuľky',
	'tout_sauvegarder' => 'Zálohovať všetky tabuľky',

	// U
	'une_donnee' => '1 záznam'
);

?>
